///File : App.cpp
//------------------------------------------------------------------------------
/*
    This file is part of LongestWord.

    LongestWord is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    LongestWord is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with LongestWord.  If not, see <http://www.gnu.org/licenses/>.
*/
//------------------------------------------------------------------------------
#include "App.hpp"
//------------------------------------------------------------------------------
IMPLEMENT_APP(App)

#ifdef __WXMAC__
    #include <ApplicationServices/ApplicationServices.h>
#endif
//------------------------------------------------------------------------------
bool App::OnInit()
{
    #ifdef __WXMAC__
    ProcessSerialNumber PSN;
    GetCurrentProcess(&PSN);
    TransformProcessType(&PSN,kProcessTransformToForegroundApplication);
    #endif
	
    // Création du Handler pour les images (permet de les ouvrir)...
    wxInitAllImageHandlers();

    // Gestion de la langue
    // Ajout des préfixes possibles de chemins d'accès aux catalogues
    wxLocale::AddCatalogLookupPathPrefix(findFile(_T("locale")));

    // Mise en place de la langue par défaut du système
    m_locale.Init(wxLANGUAGE_DEFAULT);
    {
       wxLogNull noLog; // Supprime les erreurs si les catalogues n'existent pas
       // Catalogue de l'application
       m_locale.AddCatalog(_T("lettergames"));
       // Catalogue de wxWidgets
       m_locale.AddCatalog(_T("wxstd"));
    }

    // LongestWord
    m_LongestWord.Init(GetSystemLanguage());

    try
    {
        wxString frameTitle = PROG_FULL_NAME_GETTEXT;
        #if DEBUG == 1
           frameTitle += _T(" - Debug");
        #endif

        MainFrame *frame = new MainFrame(&m_LongestWord, frameTitle,  wxDefaultPosition, wxSize(700, 200));
        frame->SetMinSize(wxSize(700, 200));
        frame->Show(true);
    }
    catch(const std::exception& e) //Rattrape toutes les exceptions
    {
        wxMessageBox(_("Error : ") + wxString(e.what(), wxConvUTF8), _("Error..."),  wxOK | wxICON_ERROR);
        exit(1);
    }

    return true;
}
//------------------------------------------------------------------------------
wxString App::GetSystemLanguage()
{
    return m_locale.GetName().Mid(0,2);
}
