///File : MainFrame.cpp
//------------------------------------------------------------------------------
/*
    This file is part of LongestWord.

    LongestWord is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    LongestWord is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with LongestWord.  If not, see <http://www.gnu.org/licenses/>.
*/
//------------------------------------------------------------------------------
#include "MainFrame.hpp"
//------------------------------------------------------------------------------
MainFrame::MainFrame(LongestWord *hangMan, const wxString& title, const wxPoint& pos, const wxSize& size, long style) : wxFrame(NULL, -1, title, pos, size, style)
{
    // LongestWord
    m_LongestWord = hangMan;

    // Presentation général
    wxString ImgFileName;
    #if defined(__WXMSW__)
        SetIcon(wxIcon(_T("win32icon")));
    #elif defined(__UNIX__)
        ImgFileName = findFile(_T("data/" PROG_PKG_NAME "-icon.png"));
        if(wxFileExists(ImgFileName))
        {
            SetIcon(wxIcon(ImgFileName, wxBITMAP_TYPE_PNG));
        }
    #endif //#ifdef WIN32
    SetBackgroundColour(wxSystemSettings::GetColour(wxSYS_COLOUR_BTNFACE));

        // File menu
    wxMenu *FileMenu = new wxMenu;
    FileMenu->Append(wxID_NEW);
    FileMenu->AppendSeparator();
    FileMenu->Append(wxID_EXIT);

        // Lang list menu
    wxMenu *LangListMenu = new wxMenu;
    wxArrayString langList = m_LongestWord->GetLanguageRealNameList();
    for(int i = 0; i < langList.GetCount(); i++)
    {
        m_MenuItemsLanguageList.push_back(LangListMenu->AppendRadioItem(Id_MenuItemsLanguageList + i, langList[i]));
        Connect( m_MenuItemsLanguageList[i]->GetId(), wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler(MainFrame::OnMenuItemsLanguageList));

        if(langList[i] == m_LongestWord->GetLanguageRealName(m_LongestWord->GetCurrentLanguage()))
        {
            m_MenuItemsLanguageList[i]->Check(true);
        }
    }


        // Option Menu
    wxMenu *OptionsMenu = new wxMenu;
    OptionsMenu->AppendSubMenu(LangListMenu, _("Word list"));

        // Help Menu
    wxMenu *HelpMenu = new wxMenu;
    HelpMenu->Append(wxID_ABOUT);

        // Menubar
    m_MenuBar = new wxMenuBar();
    m_MenuBar->Append(FileMenu,_("&File"));
    m_MenuBar->Append(OptionsMenu,_("&Options"));
    m_MenuBar->Append(HelpMenu,_("&Help"));

    SetMenuBar(m_MenuBar);


    // Body
	wxBoxSizer* MainSizer = new wxBoxSizer( wxVERTICAL );

	m_MainPanel = new MainPanel(this ,wxID_ANY, m_LongestWord);
    MainSizer->Add(m_MainPanel, 1, wxEXPAND);

	SetSizer( MainSizer );

	// Events
    Connect( wxID_NEW, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler(MainFrame::OnNew));
    Connect( wxID_EXIT, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler(MainFrame::OnQuit));
    Connect( wxID_ABOUT, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler(MainFrame::OnAbout));
}
//------------------------------------------------------------------------------
void MainFrame::OnMenuItemsLanguageList(wxCommandEvent& event)
{
    for(size_t i = 0; i < m_MenuItemsLanguageList.size(); i++)
    {
        if(event.GetId() == m_MenuItemsLanguageList[i]->GetId())
        {
            wxString chosenLanguage = m_LongestWord->GetLanguageName(m_MenuItemsLanguageList[i]->GetItemLabelText());
            if(chosenLanguage != m_LongestWord->GetCurrentLanguage())
            {
                m_LongestWord->LoadWords(chosenLanguage);
                wxMessageBox(wxString::Format(_("New language selected : %s.\nThis list contains %d words."), m_MenuItemsLanguageList[i]->GetItemLabelText().c_str(), m_LongestWord->GetWordListCount()), _("New language"), wxOK | wxICON_INFORMATION, this);
                m_MainPanel->NewLetters();
            }
            break;
        }
    }
}
//------------------------------------------------------------------------------
void MainFrame::OnQuit(wxCommandEvent& event)
{
    Close(true);
}
//------------------------------------------------------------------------------
void MainFrame::OnNew(wxCommandEvent& event)
{
    m_MainPanel->NewLetters();
}
//------------------------------------------------------------------------------
void MainFrame::OnAbout(wxCommandEvent& event)
{
    DialogAbout MyDialogAbout(this, wxID_ANY);
    MyDialogAbout.ShowModal();
}
